@@ -9,6 +9,7 @@ from .typing import (
     AfterRequestCallable,
     AfterServingCallable,
     AfterWebsocketCallable,
+    BeforeFirstRequestCallable,
     BeforeRequestCallable,
     BeforeServingCallable,
     BeforeWebsocketCallable,
@@ -297,7 +298,9 @@ class Blueprint(Scaffold):
         self.record_once(lambda state: state.app.before_serving(func))
         return func
 
-    def before_app_first_request(self, func: BeforeRequestCallable) -> BeforeRequestCallable:
+    def before_app_first_request(
+        self, func: BeforeFirstRequestCallable
+    ) -> BeforeFirstRequestCallable:
         """Add a before request first function to the app.
 
         This is designed to be used as a decorator, and has the same
@@ -338,7 +341,7 @@ class Blueprint(Scaffold):
 
         This is designed to be used as a decorator, and has the same arguments
         as :meth:`~quart.Quart.after_websocket`. It applies to all requests to the
-        ppe this blueprint is registerd on. An example usage,
+        ppe this blueprint is registered on. An example usage,
 
         .. code-block:: python
 
@@ -515,12 +518,6 @@ class Blueprint(Scaffold):
                 blueprint has been registered on the application.
         """
 
-        first_registration = True
-
-        for blueprint in app.blueprints.values():
-            if blueprint is self:
-                first_registration = False
-
         name = f"{options.get('name_prefix', '')}.{options.get('name', self.name)}".lstrip(".")
         if name in app.blueprints and app.blueprints[name] is not self:
             raise ValueError(
@@ -529,10 +526,15 @@ class Blueprint(Scaffold):
                 "Blueprints must have unique names"
             )
 
-        app.blueprints[name] = self
+        first_blueprint_registration = not any(
+            blueprint is self for blueprint in app.blueprints.values()
+        )
+        first_name_registration = name not in app.blueprints
 
+        app.blueprints[name] = self
         self._got_registered_once = True
-        state = self.make_setup_state(app, options, first_registration)
+
+        state = self.make_setup_state(app, options, first_blueprint_registration)
 
         if self.has_static_folder:
             state.add_url_rule(
@@ -541,7 +543,7 @@ class Blueprint(Scaffold):
                 endpoint="static",
             )
 
-        if first_registration:
+        if first_blueprint_registration or first_name_registration:
 
             def extend(bp_dict: dict, parent_dict: dict) -> None:
                 for key, values in bp_dict.items():
