@@ -112,6 +112,70 @@ class Config(dict):
             )
         return self.from_pyfile(value)
 
+    def from_prefixed_env(
+        self, prefix: str = "QUART", *, loads: Callable[[str], Any] = json.loads
+    ) -> bool:
+        """Load any environment variables that start with the prefix.
+
+        The prefix (default ``QUART_``) is dropped from the env key
+        for the config key. Values are passed through a loading
+        function to attempt to convert them to more specific types
+        than strings.
+
+        Keys are loaded in :func:`sorted` order.
+
+        The default loading function attempts to parse values as any
+        valid JSON type, including dicts and lists.  Specific items in
+        nested dicts can be set by separating the keys with double
+        underscores (``__``). If an intermediate key doesn't exist, it
+        will be initialized to an empty dict.
+
+        Arguments:
+            prefix: Load env vars that start with this prefix,
+                separated with an underscore (``_``).
+            loads: Pass each string value to this function and use the
+                returned value as the config value. If any error is
+                raised it is ignored and the value remains a
+                string. The default is :func:`json.loads`.
+        """
+        prefix = f"{prefix}_"
+        len_prefix = len(prefix)
+
+        for key in sorted(os.environ):
+            if not key.startswith(prefix):
+                continue
+
+            value = os.environ[key]
+
+            try:
+                value = loads(value)
+            except Exception:
+                # Keep the value as a string if loading failed.
+                pass
+
+            # Change to key.removeprefix(prefix) on Python >= 3.9.
+            key = key[len_prefix:]
+
+            if "__" not in key:
+                # A non-nested key, set directly.
+                self[key] = value
+                continue
+
+            # Traverse nested dictionaries with keys separated by "__".
+            current = self
+            *parts, tail = key.split("__")
+
+            for part in parts:
+                # If an intermediate dict does not exist, create it.
+                if part not in current:
+                    current[part] = {}
+
+                current = current[part]
+
+            current[tail] = value
+
+        return True
+
     def from_pyfile(self, filename: str, silent: bool = False) -> bool:
         """Load the configuration from a Python cfg or py file.
 
@@ -142,7 +206,7 @@ class Config(dict):
                 self.from_mapping(parser["section"])
             else:
                 module = importlib.util.module_from_spec(spec)
-                spec.loader.exec_module(module)  # type: ignore
+                spec.loader.exec_module(module)
                 self.from_object(module)
         except (FileNotFoundError, IsADirectoryError):
             if not silent:
