@@ -8,7 +8,7 @@ from werkzeug.local import ContextVar as WerkzeugContextVar, LocalProxy, LocalSt
 
 if TYPE_CHECKING:
     from .app import Quart
-    from .ctx import AppContext
+    from .ctx import _AppCtxGlobals
     from .sessions import SessionMixin
     from .wrappers import Request, Websocket
 
@@ -32,7 +32,7 @@ _request_ctx_stack = LocalStack()
 _websocket_ctx_stack = LocalStack()
 
 current_app: Quart = LocalProxy(partial(_ctx_lookup, [_app_ctx_stack], "app"))  # type: ignore
-g: AppContext = LocalProxy(partial(_ctx_lookup, [_app_ctx_stack], "g"))  # type: ignore
+g: _AppCtxGlobals = LocalProxy(partial(_ctx_lookup, [_app_ctx_stack], "g"))  # type: ignore
 request: Request = LocalProxy(partial(_ctx_lookup, [_request_ctx_stack], "request"))  # type: ignore
 session: SessionMixin = LocalProxy(partial(_ctx_lookup, [_request_ctx_stack, _websocket_ctx_stack], "session"))  # type: ignore  # noqa: E501
 websocket: Websocket = LocalProxy(partial(_ctx_lookup, [_websocket_ctx_stack], "websocket"))  # type: ignore  # noqa: E501
