@@ -4,8 +4,9 @@ from typing import Any, AnyStr, cast, Dict, Optional, overload, Tuple, TYPE_CHEC
 from urllib.parse import unquote, urlencode
 
 from hypercorn.typing import HTTPScope, Scope, WebsocketScope
-from werkzeug.datastructures import Headers
+from werkzeug.datastructures import Authorization, Headers
 from werkzeug.sansio.multipart import Data, Epilogue, Field, File, MultipartEncoder, Preamble
+from werkzeug.urls import iri_to_uri
 
 from ..datastructures import FileStorage
 from ..json import dumps
@@ -27,6 +28,7 @@ def make_test_headers_path_and_query_string(
     path: str,
     headers: Optional[Union[dict, Headers]] = None,
     query_string: Optional[dict] = None,
+    auth: Optional[Union[Authorization, Tuple[str, str]]] = None,
 ) -> Tuple[Headers, str, bytes]:
     """Make the headers and path with defaults for testing.
 
@@ -45,6 +47,12 @@ def make_test_headers_path_and_query_string(
         headers = headers
     elif headers is not None:
         headers = Headers(headers)
+
+    if auth is not None:
+        if isinstance(auth, tuple):
+            auth = Authorization("basic", {"username": auth[0], "password": auth[1]})
+        headers.setdefault("Authorization", auth.to_header())
+
     headers.setdefault("User-Agent", "Quart")
     headers.setdefault("host", app.config["SERVER_NAME"] or "localhost")
     if "?" in path and query_string is not None:
@@ -102,10 +110,10 @@ def make_test_body_with_headers(
             request_data += encoder.send_event(
                 File(name=key, filename=file_storage.filename, headers=file_storage.headers)
             )
-            chunk = file_storage.read(16384)  # type: ignore
+            chunk = file_storage.read(16384)
             while chunk != b"":
                 request_data += encoder.send_event(Data(data=chunk, more_data=True))
-                chunk = file_storage.read(16384)  # type: ignore
+                chunk = file_storage.read(16384)
             request_data += encoder.send_event(Data(data=b"", more_data=False))
         if form is not None:
             for key, value in form.items():
@@ -175,7 +183,7 @@ def make_test_scope(
         "method": method,
         "scheme": scheme,
         "path": path,
-        "raw_path": path.encode("ascii"),
+        "raw_path": iri_to_uri(path).encode("ascii"),
         "query_string": query_string,
         "root_path": root_path,
         "headers": encode_headers(headers),
