@@ -79,9 +79,16 @@ AfterWebsocketCallable = Union[
     Callable[["Response"], Optional["Response"]],
     Callable[["Response"], Awaitable[Optional["Response"]]],
 ]
-BeforeRequestCallable = Union[Callable[[], None], Callable[[], Awaitable[None]]]
+BeforeFirstRequestCallable = Union[Callable[[], None], Callable[[], Awaitable[None]]]
+BeforeRequestCallable = Union[
+    Callable[[], Optional[ResponseReturnValue]],
+    Callable[[], Awaitable[Optional[ResponseReturnValue]]],
+]
 BeforeServingCallable = Union[Callable[[], None], Callable[[], Awaitable[None]]]
-BeforeWebsocketCallable = Union[Callable[[], None], Callable[[], Awaitable[None]]]
+BeforeWebsocketCallable = Union[
+    Callable[[], Optional[ResponseReturnValue]],
+    Callable[[], Awaitable[Optional[ResponseReturnValue]]],
+]
 ErrorHandlerCallable = Union[
     Callable[[Exception], ResponseReturnValue],
     Callable[[Exception], Awaitable[ResponseReturnValue]],
@@ -93,7 +100,7 @@ TeardownCallable = Union[
 TemplateContextProcessorCallable = Union[
     Callable[[], Dict[str, Any]], Callable[[], Awaitable[Dict[str, Any]]]
 ]
-TemplateFilterCallable = Callable[[Any], str]
+TemplateFilterCallable = Callable[[Any], Any]
 TemplateGlobalCallable = Callable[[Any], Any]
 TemplateTestCallable = Callable[[Any], bool]
 URLDefaultCallable = Callable[[str, dict], None]
